#
# spec file for package typioca
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           typioca
Version:        3.1.0
Release:        1.3
Summary:        Minimal terminal based typing speed tester
License:        MIT
Group:          Productivity/Text/Utilities
URL:            https://github.com/bloznelis/typioca
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang(API) >= 1.22

%description
A typing speed tester in the terminal

Features:
- Time or word/sentence count based typing speed tests
- Proper WPM results based on https://www.speedtypingonline.com/typing-equations
- Multiple word/sentence lists made out of classical books to spice your test up
- Cursor aware word lines
- Interactive menu
- ctrl+w support
- SSH server typioca serve
- Dynamic word lists
- Custom word lists
- Linux/Mac/Win support

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       bash-completion
BuildArch:      noarch
Requires:       %{name}
Supplements:    (%{name} and bash-completion)

%description bash-completion
The official bash completion script for %{name}, generated during the build.

%package zsh-completion
Summary:        ZSH Completion for %{name}
Group:          System/Shells
BuildArch:      noarch
Requires:       %{name}
Supplements:    (%{name} and zsh)

%description zsh-completion
The official zsh completion script for %{name}, generated during the build.

%prep
%autosetup -a 1

%build
# Build the binary.
%ifnarch ppc64
export GOFLAGS="-buildmode=pie"
%endif
go build

%check
# execute the binary as a basic check
./%{name} --help

%install
# Install the binary.
install -D -m 0755 %{name} "%{buildroot}/%{_bindir}/%{name}"

# Build the shell autocomplete files
%{buildroot}/%{_bindir}/%{name} completion bash > %{name}-autocomplete.bash
%{buildroot}/%{_bindir}/%{name} completion zsh > %{name}-autocomplete.zsh

# Install the shell autocomplete files
install -Dm 644 %{name}-autocomplete.bash %{buildroot}%{_datadir}/bash-completion/completions/%{name}
install -Dm 644 %{name}-autocomplete.zsh %{buildroot}%{_datadir}/zsh/site-functions/_%{name}

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}

%files bash-completion
%{_datadir}/bash-completion

%files zsh-completion
%{_datadir}/zsh

%changelog
* Sat Oct  5 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to version 3.1.0:
  * Dependency bumps
* Wed Jul 17 2024 kskarthik@disroot.org
- Update to version 3.0.0:
  * chore: bump dependencies
  * Bump golang.org/x/term from 0.18.0 to 0.22.0 (#157)
  * Bump github.com/charmbracelet/bubbletea from 0.25.0 to 0.26.6 (#152)
  * feat: add Dvorak emulation layout (#156)
  * Add keyboard layout emulation (#154)
  * add openSUSE install instruction
* Fri Jun 14 2024 Sai Karthik Karra <kskarthik@disroot.org>
- Packaging improvements:
  * Added Requires Field for shell completion packages
  * Fix rpm lint for incorrect non-standard-group
  * Temporarily bump Release: 1, revert to 0 on next version update
* Thu Jun  6 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Packaging improvements:
  * Summary and Description clarify the purpose of this TUI tool
  * Remove unused BuildRequires: zstd does not match archive format
  * _service recompress change from xz to gz. The source archive is
    not large and xz unpack times are noticeably slower. If gz is
    not ideal for a given application, zstd is a good alternative.
  * Normalize go build invocation extracted from upstream Makefile
  * Build PIE with pattern that may become recommended procedure:
    %%%%ifnarch ppc64 GOFLAGS="-buildmode=pie" %%%%endif go build
    A go toolchain buildmode default config would be preferable
    but none exist at this time.
  * Drop mod=vendor, go1.14+ will detect vendor dir and auto-enable
  * Remove go build -a forced rebuild of packages. Rebuild is not
    needed in an OBS rpmbuild environment.
  * Remove forced use of pure Go DNS resolver via -tags netgo or
    GODEBUG=netdns=go. The Go DNS resolver is already the default
    (https://pkg.go.dev/net#hdr-Name_Resolution).
  * Remove ldflags -X entries for upstream import path and version.
    This information is embedded in binaries with go1.18+ and
    available via go version -m or runtime/debug.ReadBuildInfo().
  * Move %%check section directly after %%build
* Sun Jun  2 2024 Sai Karthik Karra <kskarthik@disroot.org>
- Update to version 2.11.2:
  * fix: AUR PKGBUILD template
  * fix: specify more concrete go version
  * feat: improves how words are randomized (#141)
  * Bump softprops/action-gh-release from 1 to 2 (#136)
  * Bump github.com/guptarohit/asciigraph from 0.5.6 to 0.7.1 (#138)
  * Bump github.com/charmbracelet/wish from 1.3.1 to 1.3.2 (#137)
  * Bump github.com/charmbracelet/lipgloss from 0.9.1 to 0.10.0 (#139)
  * Bump golang.org/x/term from 0.16.0 to 0.18.0 (#140)
  * docs: add nix installation instruction
  * Bump actions/upload-artifact from 3 to 4 (#126)
